@@ -50,19 +50,12 @@ func main() {
 		panic(err)
 	}
 
-	removeUnreleasedDocs()
-
 	if err := os.Setenv("HOME", currentHOME); err != nil {
 		panic(err)
 	}
 }
 
-// removeUnreleasedDocs hides documentation for unreleased features
-func removeUnreleasedDocs() {
-	removeUnreleasedCommands("iam group-mapping")
-}
-
-func removeUnreleasedCommands(command string) {
+func removeUnreleasedCommands(command string) { //nolint:unused
 	subcommands := strings.Split(command, " ")
 
 	line := fmt.Sprintf(`\s{3}%s/index\n`, subcommands[len(subcommands)-1])
@@ -89,7 +82,7 @@ func removeUnreleasedCommands(command string) {
 	}
 }
 
-func removeLineFromFile(line, file string) error {
+func removeLineFromFile(line, file string) error { //nolint:unused
 	out, err := os.ReadFile(file)
 	if err != nil {
 		return err
