@@ -17,7 +17,7 @@ import (
 
 type command struct {
 	*pcmd.AuthenticatedCLICommand
-	keystore     keystore.KeyStore
+	keystore     *keystore.ConfigKeyStore
 	flagResolver pcmd.FlagResolver
 }
 
@@ -36,7 +36,7 @@ const (
 	unableToStoreApiKeyErrorMsg         = "unable to store API key locally: %w"
 )
 
-func New(prerunner pcmd.PreRunner, keystore keystore.KeyStore, resolver pcmd.FlagResolver) *cobra.Command {
+func New(prerunner pcmd.PreRunner, resolver pcmd.FlagResolver) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:         "api-key",
 		Short:       "Manage API keys.",
@@ -45,7 +45,6 @@ func New(prerunner pcmd.PreRunner, keystore keystore.KeyStore, resolver pcmd.Fla
 
 	c := &command{
 		AuthenticatedCLICommand: pcmd.NewAuthenticatedCLICommand(cmd, prerunner),
-		keystore:                keystore,
 		flagResolver:            resolver,
 	}
 
@@ -203,7 +202,7 @@ func (c *command) resolveResourceId(cmd *cobra.Command, v2Client *ccloudv2.Clien
 	case presource.Cloud:
 		break
 	case presource.KafkaCluster:
-		cluster, err := c.Context.FindKafkaCluster(resource)
+		cluster, err := c.Context.FindKafkaCluster(c.V2Client, resource)
 		if err != nil {
 			return "", "", "", errors.CatchResourceNotFoundError(err, resource)
 		}
