@@ -23,7 +23,7 @@ func New(cfg *config.Config, prerunner pcmd.PreRunner) *cobra.Command {
 		cmd.Long = "Manage Role-Based Access Control (RBAC) and Identity and Access Management (IAM) permissions."
 	}
 
-	dc := dynamicconfig.New(cfg, nil)
+	dc := dynamicconfig.New(cfg)
 	_ = dc.ParseFlagsIntoConfig(cmd)
 	if cfg.IsTest || featureflags.Manager.BoolVariation("cli.iam.group_mapping.enable", dc.Context(), config.CliLaunchDarklyClient, true, false) {
 		cmd.AddCommand(newGroupMappingCommand(prerunner))
