@@ -27,7 +27,7 @@ func New(cfg *config.Config, prerunner pcmd.PreRunner) *cobra.Command {
 	cmd.AddCommand(newReplicaCommand(prerunner))
 	cmd.AddCommand(newTopicCommand(cfg, prerunner))
 
-	dc := dynamicconfig.New(cfg, nil)
+	dc := dynamicconfig.New(cfg)
 	_ = dc.ParseFlagsIntoConfig(cmd)
 	if cfg.IsTest || featureflags.Manager.BoolVariation("cli.client_quotas.enable", dc.Context(), config.CliLaunchDarklyClient, true, false) {
 		cmd.AddCommand(newQuotaCommand(prerunner))
