@@ -6,7 +6,7 @@ import (
 
 	ccloudv1 "github.com/confluentinc/ccloud-sdk-go-v1-public"
 
-	"github.com/confluentinc/cli/v3/pkg/ccloudv2"
+	"github.com/confluentinc/cli/v3/pkg/auth/sso"
 	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/output"
 	testserver "github.com/confluentinc/cli/v3/test/test-server"
@@ -79,35 +79,11 @@ func (c *Context) Save() error {
 }
 
 func (c *Context) HasBasicMDSLogin() bool {
-	if c.Credential == nil {
-		return false
-	}
-
-	credType := c.GetCredentialType()
-	switch credType {
-	case Username:
-		return c.GetAuthToken() != ""
-	case APIKey:
-		return false
-	default:
-		panic(fmt.Sprintf("unknown credential type %d in context '%s'", credType, c.Name))
-	}
+	return c.GetCredentialType() == Username && c.GetAuthToken() != ""
 }
 
 func (c *Context) hasBasicCloudLogin() bool {
-	if c.Credential == nil {
-		return false
-	}
-
-	credType := c.GetCredentialType()
-	switch credType {
-	case Username:
-		return c.GetAuthToken() != "" && c.GetCurrentEnvironment() != ""
-	case APIKey:
-		return false
-	default:
-		panic(fmt.Sprintf("unknown credential type %d in context '%s'", credType, c.Name))
-	}
+	return c.GetCredentialType() == Username && c.GetAuthToken() != "" && c.GetCurrentEnvironment() != ""
 }
 
 func (c *Context) DeleteUserAuth() error {
@@ -137,7 +113,7 @@ func (c *Context) IsCloud(isTest bool) bool {
 		return true
 	}
 
-	for _, hostname := range ccloudv2.Hostnames {
+	for _, hostname := range []string{"confluent.cloud", "confluentgov-internal.com", "confluentgov.com", "cpdev.cloud"} {
 		if strings.Contains(c.PlatformName, hostname) {
 			return true
 		}
@@ -389,6 +365,52 @@ func (c *Context) GetNetrcMachineName() string {
 	return ""
 }
 
+func (c *Context) RefreshSession(client *ccloudv1.Client) error {
+	if c.IsSso() {
+		idToken, refreshToken, err := sso.RefreshTokens(client.BaseURL, c.GetAuthRefreshToken())
+		if err != nil {
+			return err
+		}
+
+		req := &ccloudv1.AuthenticateRequest{
+			IdToken:       idToken,
+			OrgResourceId: c.GetCurrentOrganization(),
+		}
+
+		var res *ccloudv1.AuthenticateReply
+		if sso.IsOkta(client.BaseURL) {
+			res, err = client.Auth.OktaLogin(req)
+		} else {
+			res, err = client.Auth.Login(req)
+		}
+		if err != nil {
+			return err
+		}
+
+		c.State.AuthToken = res.GetToken()
+		c.State.AuthRefreshToken = refreshToken
+	} else {
+		req := &ccloudv1.AuthenticateRequest{
+			RefreshToken:  c.GetAuthRefreshToken(),
+			OrgResourceId: c.GetCurrentOrganization(),
+		}
+
+		res, err := client.Auth.Login(req)
+		if err != nil {
+			return err
+		}
+
+		c.State.AuthToken = res.GetToken()
+		c.State.AuthRefreshToken = res.GetRefreshToken()
+	}
+
+	return nil
+}
+
+func (c *Context) IsSso() bool {
+	return c.GetUser().GetAuthType() == ccloudv1.AuthType_AUTH_TYPE_SSO || c.GetUser().GetSocialConnection() != ""
+}
+
 func printApiKeysDictErrorMessage(missingKey, mismatchKey, missingSecret bool, cluster *KafkaClusterConfig, contextName string) {
 	var problems []string
 	if missingKey {
